PyTables Development — PyTables 3.1.1 documentation

### Navigation

- index
- modules
- modules
- next
- previous
- PyTables 3.1.1 documentation »

# PyTables Development

If you want to follow the development of PyTables and take part in it, you may have a look at the PyTables project pages on GitHub.

The source code for PyTables may be found at the GitHub project site. You can get a copy of the latest version of the source code (under development) from the master branch of the project repository using git:

    git clone git@github.com:PyTables/PyTables.git

Also, be sure to subscribe to the Users’ Mailing List and/or the Developers’ Mailing List.

Other resources for developers:

- GitHub project site
- Library Reference
- Git Repository browser
- Issue tracker
- Developers wiki
- Users’ Mailing List
- Developers’ Mailing List
- Continuous Integration:
  - master branch at OME
  - develop branch at Shining Panda
  - all branches on Travis-CI
- Old trac site

- Dev IRC Meetings

### Navigation

- index
- modules
- modules
- next
- previous
- PyTables 3.1.1 documentation »